@@ -10,11 +10,11 @@ let () =
           | None -> default
           | Some pc -> (
               match
-                C.Pkg_config.query_expr_err pc
-                  ~package:"fdk-aac" ~expr:"fdk-aac >= 0.1.1"
+                C.Pkg_config.query_expr_err pc ~package:"fdk-aac"
+                  ~expr:"fdk-aac >= 0.1.1"
               with
                 | Error msg -> failwith msg
-                | Ok deps -> deps )
+                | Ok deps -> deps)
       in
-      C.Flags.write_sexp "c_flags.sexp" conf.cflags;
+      C.Flags.write_sexp "c_flags.sexp" ("-fPIC" :: conf.cflags);
       C.Flags.write_sexp "c_library_flags.sexp" conf.libs)
